==> ruby-web-common-1.1.1.tgz: package/src/components/validated_input/index.tsx <==
// node modules
import React, { ChangeEvent, FC, useState, KeyboardEvent, useRef } from 'react';
import keys from 'lodash/keys';
import debounce from 'lodash/debounce';

// local components
import { Input, InputProps } from "../input";
import { Typography } from "../typography";


// local files
import { validator } from "./validator";
import { theming } from "../../theme";
import { useStyles } from "./styles";

const NUMBER_TYPE = 'number';

export type ValidationQueryType = {
    value: string | number,
    errorMessage?: string
}

export type ValidationTypeProps = {
    value: 'emptyString' | 'email' | 'number',
    errorMessage?: string
}

export interface ValidatedInputProps extends InputProps{
    errorText?: boolean,
    onError?: (invalid: boolean) => void,
    validationQuery?: {
        minLength?: ValidationQueryType,
        maxLength?: ValidationQueryType,
        type?: ValidationTypeProps
    },
    onKeyDown?: (e: KeyboardEvent) => void,
    errorDelay?: boolean,
    errorDelayTime?: number
}


export const ValidatedInput: FC<ValidatedInputProps> = ({
    errorText,
    onError,
    onChange,
    validationQuery = { type: 'emptyString' },
    errorDelay = false,
    errorDelayTime = 300,
    ...otherProps
}) => {
    const { errorMessageClass } = useStyles({ theme: theming.useTheme() })
    const [errors, setErrors] = useState<any>([]);
    const { type } = validationQuery;
    // @ts-ignore
    const isNumberType = Boolean(type && (type.value === NUMBER_TYPE));

    const toggleError = (errors: any) => {
        if (onError) onError(Boolean(errors.length))

        setErrors(errors);
    }

    const { current: delayedToggleError } = useRef(
        debounce(toggleError, errorDelayTime)
    );

    const validate = (value: string) => {
        const errors = keys(validationQuery).reduce((err, key) => {
            // @ts-ignore
            const paramValidator = validator[key];

            if (paramValidator) {
                // @ts-ignore
                const param = validationQuery[key];
                // @ts-ignore
                const error = paramValidator(value, param);
                // @ts-ignore
                if (error) err.push(param);
            }

            return err;
        }, [])

        if (errorDelay) delayedToggleError(errors)
        else toggleError(errors);
    }

    const handleChange = (e: ChangeEvent<HTMLInputElement> | Event) => {
        // @ts-ignore
        if (!isNumberType) validate(e.target.value);

        if(onChange) onChange(e);
    }

    const handleKeyDown = (e: KeyboardEvent) => {
        const { onKeyDown } = otherProps;

        if (onKeyDown) onKeyDown(e);

        if (!isNumberType) return;

        const regexp = /[0-9]/;
        const isBackspace = e.key === 'Backspace';
        const isNotNumber = !regexp.test(e.key) && !isBackspace;

        if (isNotNumber) e.preventDefault();
    };

    const isErrorMessageExist = errors[0] && errors[0].errorMessage;

    return (
        <div>
            <Input
                onKeyDown={handleKeyDown}
                onChange={handleChange}
                error={Boolean(errors[0])}
                {...otherProps}
            />
            {isErrorMessageExist && (
                <Typography
                    className={errorMessageClass}
                    variant="label">
                    {errors[0].errorMessage}
                </Typography>
            )}
        </div>
    )
}

==> ruby-web-common-1.1.4.tgz: package/src/components/validated_input/index.tsx <==
// node modules
import React, { ChangeEvent, FC, useState, KeyboardEvent, useRef } from 'react';
import keys from 'lodash/keys';
import debounce from 'lodash/debounce';

// local components
import { Input, InputProps } from "../input";
import { Typography } from "../typography";


// local files
import { validator, numberValidator } from "./validator";
import { theming } from "../../theme";
import { useStyles } from "./styles";

const NUMBER_TYPE = 'number';

const numberKeys = {
    lessThen: true,
    moreThen: true,
    equal: true
}

export type ValidationQueryType = {
    value: string | number,
    errorMessage?: string
}

export type ValidationTypeProps = {
    value: 'emptyString' | 'email' | 'number',
    errorMessage?: string,
    lessThen?: ValidationQueryType,
    moreThen?: ValidationQueryType,
    equal?: ValidationQueryType
}

export interface ValidatedInputProps extends InputProps{
    errorText?: boolean,
    onError?: (invalid: boolean) => void,
    validationQuery?: {
        minLength?: ValidationQueryType,
        maxLength?: ValidationQueryType,
        type?: ValidationTypeProps
    },
    onKeyDown?: (e: KeyboardEvent) => void,
    errorDelay?: boolean,
    errorDelayTime?: number
}


export const ValidatedInput: FC<ValidatedInputProps> = ({
    errorText,
    onError,
    onChange,
    validationQuery = { type: 'emptyString' },
    errorDelay = false,
    errorDelayTime = 300,
    ...otherProps
}) => {
    const { errorMessageClass } = useStyles({ theme: theming.useTheme() })
    const [errors, setErrors] = useState<any>([]);
    const { type } = validationQuery;
    // @ts-ignore
    const isNumberType = Boolean(type && (type.value === NUMBER_TYPE));

    const toggleError = (errors: any) => {
        if (onError) onError(Boolean(errors.length))

        setErrors(errors);
    }

    const { current: delayedToggleError } = useRef(
        debounce(toggleError, errorDelayTime)
    );

    const validate = (value: string) => {
        const errors = keys(validationQuery).reduce((err, key) => {
            // @ts-ignore
            const paramValidator = validator[key];

            if (paramValidator) {
                // @ts-ignore
                const param = validationQuery[key];
                // @ts-ignore
                const error = paramValidator(value, param);
                // @ts-ignore
                if (error) err.push(param);
            }

            return err;
        }, [])

        if (errorDelay) delayedToggleError(errors)
        else toggleError(errors);
    }

    const validateNumber = (value: string) => {

        const errors = keys(type).reduce((err, key) => {
            // @ts-ignore
            const isCorrectKey = Boolean(numberKeys[key]);

            if(isCorrectKey) {
                // @ts-ignore
                const param = type[key];
                // @ts-ignore
                const error = numberValidator[key](Number(value), param)
                // @ts-ignore
                if(error) err.push(param)
            }

            return err;
        }, []);

        if (errorDelay) delayedToggleError(errors)
        else toggleError(errors);
    }


    const handleChange = (e: ChangeEvent<HTMLInputElement> | Event) => {
        // @ts-ignore
        const { value } = e.target;

        if (!isNumberType) validate(value);
        else validateNumber(value)

        if(onChange) onChange(e);
    }

    const handleKeyDown = (e: KeyboardEvent) => {
        const { onKeyDown } = otherProps;

        if (onKeyDown) onKeyDown(e);

        if (!isNumberType) return;

        const regexp = /[0-9]/;
        const isBackspace = e.key === 'Backspace';
        const isNotNumber = !regexp.test(e.key) && !isBackspace;

        if (isNotNumber) e.preventDefault();
    };

    const isErrorMessageExist = errors[0] && errors[0].errorMessage;

    return (
        <div>
            <Input
                onKeyDown={handleKeyDown}
                onChange={handleChange}
                error={Boolean(errors[0])}
                {...(isNumberType ? { pattern: "[0-9]*" }: {})}
                {...otherProps}
            />
            {isErrorMessageExist && (
                <Typography
                    className={errorMessageClass}
                    variant="label">
                    {errors[0].errorMessage}
                </Typography>
            )}
        </div>
    )
}
